box_surv: box_surv

View source: R/11_surv_box_plot.R

box_survR Documentation

box_surv

Description

draw box plot for a hub gene expression matrix

Usage

box_surv(
  exp_hub,
  exprSet_hub,
  meta,
  xlab = "Group",
  ylab = "Expression",
  p.label = FALSE
)

Arguments

exp_hub

an expression matrix for hubgenes

exprSet_hub

a tumor expression set for hubgenes

meta

meta data corresponds to expression set

xlab

x axis title for the boxplot

ylab

y axis title for the boxplot

p.label

whether to show the exact p-value, if FALSE show significance symbols

Value

patchwork result for hub genes boxplot and survival plot

Author(s)

Xiaojie Sun

See Also

exp_boxplot;exp_surv

Examples


k = box_surv(log2(exp_hub1+1),exprSet_hub1,meta1);k[[1]]


tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.