double_enrich: draw enrichment bar plots for both up and down genes

View source: R/7_quick_double_enrich.R

double_enrichR Documentation

draw enrichment bar plots for both up and down genes

Description

draw enrichment bar plots for both up and down genes,for human only.

Usage

double_enrich(deg, n = 10, color = c("#2874C5", "#f87669"), species = "human")

Arguments

deg

a data.frame contains at least two columns:"ENTREZID" and "change"

n

how many terms will you perform for up and down genes respectively

color

color for bar plot

species

choose human, mouse, or rat; default is human

Value

a list with kegg and go bar plot according to up and down genes enrichment result.

Author(s)

Xiaojie Sun

See Also

quick_enrich

Examples

## Not run: 
deg = data.frame(
  ENTREZID = genes[1:20],
  change = rep(c("up", "down"), 10)
)
double_enrich(deg)

## End(Not run)

tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.