draw boxplot for expression
draw_boxplot(
exp,
group_list,
method = "kruskal.test",
sort = TRUE,
drop = FALSE,
width = 0.5,
pvalue_cutoff = 0.05,
xlab = "Gene",
ylab = "Expression",
grouplab = "Group",
p.label = FALSE,
add_error_bar = FALSE,
color = c("#2874C5", "#f87669", "#e6b707", "#868686", "#66C2A5", "#FC8D62", "#8DA0CB",
"#E78AC3", "#A6D854", "#FFD92F", "#E5C494", "#B3B3B3"),
...
)a boxplot according to exp and grouped by group.
A numeric matrix
A character or factor vector with one label per sample; character input will be converted to factor and unused levels will be dropped.
one of kruskal.test,aov,t.test and wilcox.test
whether the boxplot will be sorted
whether to discard insignificant values
width of boxplot and error bar
if drop = TRUE,genes with p-values below the threshold will be drawn
title of the x axis
title of the y axis
title of group legend
whether to show the exact p value in the plot; if `FALSE`, show significance stars
whether to add error bar
color vector
other parameters from stat_compare_means
Xiaojie Sun
draw_heatmap;draw_volcano;draw_venn