Learn R Programming

tinyarray (version 3.0.0)

draw_heatmap: draw a heatmap plot

Description

draw a heatmap plot for an expression matrix grouped by group_list; if scale = TRUE, the matrix is scaled before plotting.

Usage

draw_heatmap(
  n,
  group_list,
  scale_before = FALSE,
  n_cutoff = 3,
  legend = FALSE,
  show_rownames = FALSE,
  annotation_legend = FALSE,
  split_column = FALSE,
  show_column_title = FALSE,
  color = (grDevices::colorRampPalette(c("#2fa1dd", "white", "#f87669")))(100),
  color_an = c("#2fa1dd", "#f87669", "#e6b707", "#868686", "#92C5DE", "#F4A582",
    "#66C2A5", "#FC8D62", "#8DA0CB", "#E78AC3", "#A6D854", "#FFD92F", "#E5C494",
    "#B3B3B3"),
  scale = TRUE,
  main = NA,
  ...
)

Value

a heatmap plot according to n and grouped by

group_list.

Arguments

n

A numeric matrix

group_list

A character or factor vector with one label per sample; character input will be converted to factor and unused levels will be dropped.

scale_before

deprecated parameter

n_cutoff

numeric cutoff used after scaling; values outside [-n_cutoff, n_cutoff] are truncated before plotting.

legend

logical,show legend or not

show_rownames

logical,show rownames or not

annotation_legend

logical,show annotation legend or not

split_column

split column by group_list

show_column_title

show column title or not

color

color for heatmap

color_an

color for column annotation

scale

logical,scale the matrix or not

main

the title of the plot

...

other parameters from pheatmap

Author

Xiaojie Sun

See Also

draw_pca;draw_volcano;draw_venn