draw_pca: draw PCA plots

View source: R/1_plots.R

draw_pcaR Documentation

draw PCA plots

Description

do PCA analysis and warning a PCA plot

Usage

draw_pca(
  exp,
  group_list,
  color = c("#2874C5", "#f87669", "#e6b707", "#868686", "#92C5DE", "#F4A582", "#66C2A5",
    "#FC8D62", "#8DA0CB", "#E78AC3", "#A6D854", "#FFD92F", "#E5C494", "#B3B3B3"),
  addEllipses = TRUE,
  style = "default",
  color.label = "Group",
  title = "",
  ...
)

Arguments

exp

A numeric matrix

group_list

A character or factor vector with one label per sample; character input will be converted to factor and unused levels will be dropped.

color

color vector

addEllipses

logical,add ellipses or not

style

plot style,"default","ggplot2"and "3D"

color.label

color legend label

title

plot title

...

other parameters from fviz_pca_ind

Value

a PCA plot according to exp and grouped by group_list.

Author(s)

Xiaojie Sun

See Also

draw_heatmap;draw_volcano;draw_venn

Examples


draw_pca(t(iris[,1:4]),iris$Species)
#change color
draw_pca(t(iris[,1:4]),iris$Species,color = c("#E78AC3", "#A6D854", "#FFD92F"))


draw_pca(t(iris[,1:4]),iris$Species,style = "ggplot2")


draw_pca(t(iris[,1:4]),iris$Species,style = "3D")


tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.