exp_boxplot: exp_boxplot

View source: R/11_surv_box_plot.R

exp_boxplotR Documentation

exp_boxplot

Description

draw box plot for a hub gene expression matrix

Usage

exp_boxplot(
  exp_hub,
  xlab = NULL,
  ylab = NULL,
  p.label = FALSE,
  color = c("#2fa1dd", "#f87669")
)

Arguments

exp_hub

an expression matrix for hubgenes

xlab

x axis title

ylab

y axis title

p.label

whether to show the exact p-value, if FALSE show significance symbols

color

color for boxplot

Value

box plots list for all genes in the matrix

Author(s)

Xiaojie Sun

See Also

exp_surv;box_surv

Examples


k = exp_boxplot(log2(exp_hub1+1));k[[1]]


tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.