find_anno: Find an annotation table for a GEO platform accession.

View source: R/2_geo_id.R

find_annoR Documentation

Find an annotation table for a GEO platform accession.

Description

The function prints a short explanation plus the code used to obtain annotations. It only tests AnnoProbe 'type' values when no Bioconductor annotation package source exists for the GPL accession.

Usage

find_anno(gpl, install = FALSE, update = FALSE)

Arguments

gpl

a GEO platform accession

install

whether to install and library the package

update

whether to update the package

Value

No return value. The function prints available annotation resources and optionally installs a Bioconductor annotation package.

Author(s)

Xiaojie Sun

See Also

geo_download

Examples

## Not run: 
try(find_anno("GPL570"), silent = TRUE)

## End(Not run)

tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.