get_deg: get_deg

View source: R/3_get_deg.R

get_degR Documentation

get_deg

Description

Do differential analysis according to an expression set and group information.

Usage

get_deg(
  exp,
  group_list,
  ids = NULL,
  logFC_cutoff = 1,
  pvalue_cutoff = 0.05,
  adjust = TRUE,
  entriz = TRUE,
  species = "human"
)

Arguments

exp

A numeric matrix

group_list

A character or factor vector with one label per sample; character input will be converted to factor and unused levels will be dropped.

ids

optional probe-to-symbol annotation table. If 'NULL', 'exp' is treated as a gene-level matrix and no ID conversion is performed.

logFC_cutoff

Cutoff value of logFC,1 by default.

pvalue_cutoff

Cutoff value of pvalue,0.05 by default.

adjust

a logical value; if TRUE, use padj and plot -log10(padj); otherwise use P.value and plot -log10(P.value).

entriz

whether to convert symbols to Entrez IDs

species

choose human, mouse, or rat; default is human

Value

a deg data.frame

Author(s)

Xiaojie Sun

See Also

multi_deg;get_deg_all

Examples

## Not run: 
if(requireNamespace("Biobase",quietly = TRUE)&
   requireNamespace("AnnoProbe",quietly = TRUE)){
  gse = "GSE42872"
  a = geo_download(gse,destdir=tempdir())
  find_anno(geo$gpl)
  ids <- AnnoProbe::idmap(geo$gpl,destdir = tempdir())
  Group = rep(c("control","treat"),each = 3)
  Group = factor(Group)
  deg = get_deg(geo$exp,Group,ids,entriz = FALSE)
  head(deg)
}else{
  if(!requireNamespace("AnnoProbe",quietly = TRUE)) {
    warning("Package 'AnnoProbe' needed for this function to work.
         Please install it by install.packages('AnnoProbe')",call. = FALSE)
  }
  if(!requireNamespace("Biobase",quietly = TRUE)) {
    warning("Package 'Biobase' needed for this function to work.
         Please install it by BiocManager::install('Biobase')",call. = FALSE)
  }
}

## End(Not run)

tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.