make_tcga_group: make_tcga_group

View source: R/8_tcga_group_trans_exp.R

make_tcga_groupR Documentation

make_tcga_group

Description

make tcga group for given tcga sample names or expression matrix

Usage

make_tcga_group(exp)

Arguments

exp

sample names or an expression matrix/data.frame with sample names in its columns

Value

a group factor with normal and tumor, corresponding to the sample names

Author(s)

Xiaojie Sun

See Also

sam_filter;match_exp_cl

Examples

k = make_tcga_group(exp_hub1);table(k)
k2 = make_tcga_group(colnames(exp_hub1));table(k2)

tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.