Learn R Programming

tinyarray (version 3.0.0)

surv_cox: surv_cox

Description

calculate cox p values and HR for genes

Usage

surv_cox(
  exprSet_hub,
  meta,
  cut.point = FALSE,
  pvalue_cutoff = 0.05,
  HRkeep = "all",
  continuous = FALSE,
  min_gn = 0.1
)

Value

a matrix with gene names ,cox p value and HR

Arguments

exprSet_hub

a tumor expression set for hubgenes

meta

meta data corresponds to expression set

cut.point

logical, whether to use cut_point; if FALSE, use the median as the cutoff.

pvalue_cutoff

p value cut off ,0.05 by defult

HRkeep

one of "all","protect"or"risk"

continuous

logical, gene expression or gene expression group

min_gn

Depending on the expression of a gene, there may be a large difference in sample counts between the two groups. If the smaller group contains less than 10 percent of all samples, the gene will be discarded.

Author

Xiaojie Sun

See Also

point_cut;surv_KM

Examples

Run this code
surv_cox(exprSet_hub1,meta1)
surv_cox(exprSet_hub1,meta1,cut.point = TRUE,continuous = TRUE)
surv_cox(exprSet_hub1,meta1,cut.point = TRUE,continuous = TRUE,pvalue_cutoff = 1)

Run the code above in your browser using DataLab