trans_array: trans_array

View source: R/8_tcga_group_trans_exp.R

trans_arrayR Documentation

trans_array

Description

transform rownames for microarray or rnaseq expression matrix

Usage

trans_array(exp, ids, from = "probe_id", to = "symbol", average = FALSE)

Arguments

exp

microarray or RNA-seq expression matrix

ids

data.frame with original rownames and new rownames

from

colname for original rownames

to

colname for new rownames

average

logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.

Value

a transformed expression set with new rownames

Author(s)

Xiaojie Sun

See Also

trans_exp

Examples

exp = matrix(1:50,nrow = 10)
rownames(exp) = paste0("g",1:10)
ids = data.frame(probe_id = paste0("g",1:10),
                symbol = paste0("G",c(1:9,9)))
trans_array(exp,ids)
trans_array(exp,ids,average = TRUE)

tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.