trans_ensembl_exp: trans_ensembl_exp

View source: R/8_tcga_group_trans_exp.R

trans_ensembl_expR Documentation

trans_ensembl_exp

Description

Transform rownames of an expression set from Ensembl IDs to gene symbols using the latest gene annotation.

Usage

trans_ensembl_exp(
  exp,
  mrna_only = FALSE,
  lncrna_only = FALSE,
  species = "human",
  average = FALSE
)

Arguments

exp

expression matrix with Ensembl IDs as rownames

mrna_only

only keep mrna rows in result

lncrna_only

only keep lncrna rows in result

species

choose human, mouse, or rat; default is human

average

logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.

Value

a transformed expression set with symbol

Author(s)

Xiaojie Sun

See Also

trans_exp_new

Examples


exp = matrix(rnorm(1000),ncol = 10)
rownames(exp) = sample(mRNA_anno$gene_id,100)
colnames(exp) = c(paste0("TCGA",1:5),paste0("GTEX",1:5))
k  = trans_ensembl_exp(exp)


tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.