trans_entrezexp: trans_entrezexp

View source: R/8_tcga_group_trans_exp.R

trans_entrezexpR Documentation

trans_entrezexp

Description

Transform rownames of an expression set from Entrez IDs to gene symbols using clusterProfiler::bitr().

Usage

trans_entrezexp(entrezexp, species = "human", average = FALSE)

trans_entrez_exp(entrezexp, species = "human", average = FALSE)

Arguments

entrezexp

expression matrix with Entrez IDs as rownames

species

choose human, mouse, or rat; default is human

average

logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.

Value

a transformed expression set with symbol

Author(s)

Xiaojie Sun

See Also

trans_exp

Examples


exp = matrix(rnorm(200),ncol = 10)
rownames(exp) = c("79691", "56271", "8662", "10394", "55630", "159162", "23541",
                  "79723", "54413", "22927", "92342", "23787", "5550", "8924",
                  "55274", "866", "8844", "353299", "587", "1473")
colnames(exp) = paste0("s",1:10)
exp2 = trans_entrezexp(exp)


tinyarray documentation built on Aug. 2, 2026, 9:07 a.m.