View source: R/11_surv_box_plot.R
| box_surv | R Documentation |
draw box plot for a hub gene expression matrix
box_surv(
exp_hub,
exprSet_hub,
meta,
xlab = "Group",
ylab = "Expression",
p.label = FALSE
)
exp_hub |
an expression matrix for hubgenes |
exprSet_hub |
a tumor expression set for hubgenes |
meta |
meta data corresponds to expression set |
xlab |
x axis title for the boxplot |
ylab |
y axis title for the boxplot |
p.label |
whether to show the exact p-value, if FALSE show significance symbols |
patchwork result for hub genes boxplot and survival plot
Xiaojie Sun
exp_boxplot;exp_surv
k = box_surv(log2(exp_hub1+1),exprSet_hub1,meta1);k[[1]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.