Learn R Programming

tinyarray (version 3.0.0)

box_surv: box_surv

Description

draw box plot for a hub gene expression matrix

Usage

box_surv(
  exp_hub,
  exprSet_hub,
  meta,
  xlab = "Group",
  ylab = "Expression",
  p.label = FALSE
)

Value

patchwork result for hub genes boxplot and survival plot

Arguments

exp_hub

an expression matrix for hubgenes

exprSet_hub

a tumor expression set for hubgenes

meta

meta data corresponds to expression set

xlab

x axis title for the boxplot

ylab

y axis title for the boxplot

p.label

whether to show the exact p-value, if FALSE show significance symbols

Author

Xiaojie Sun

See Also

exp_boxplot;exp_surv