draw box plot for a hub gene expression matrix
box_surv(
exp_hub,
exprSet_hub,
meta,
xlab = "Group",
ylab = "Expression",
p.label = FALSE
)patchwork result for hub genes boxplot and survival plot
an expression matrix for hubgenes
a tumor expression set for hubgenes
meta data corresponds to expression set
x axis title for the boxplot
y axis title for the boxplot
whether to show the exact p-value, if FALSE show significance symbols
Xiaojie Sun
exp_boxplot;exp_surv