View source: R/7_quick_double_enrich.R
| double_enrich | R Documentation |
draw enrichment bar plots for both up and down genes,for human only.
double_enrich(deg, n = 10, color = c("#2874C5", "#f87669"), species = "human")
deg |
a data.frame contains at least two columns:"ENTREZID" and "change" |
n |
how many terms will you perform for up and down genes respectively |
color |
color for bar plot |
species |
choose human, mouse, or rat; default is human |
a list with kegg and go bar plot according to up and down genes enrichment result.
Xiaojie Sun
quick_enrich
## Not run:
deg = data.frame(
ENTREZID = genes[1:20],
change = rep(c("up", "down"), 10)
)
double_enrich(deg)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.