powered by
draw enrichment bar plots for both up and down genes,for human only.
double_enrich(deg, n = 10, color = c("#2874C5", "#f87669"), species = "human")
a list with kegg and go bar plot according to up and down genes enrichment result.
a data.frame contains at least two columns:"ENTREZID" and "change"
how many terms will you perform for up and down genes respectively
color for bar plot
choose human, mouse, or rat; default is human
Xiaojie Sun
quick_enrich
if (FALSE) { deg = data.frame( ENTREZID = genes[1:20], change = rep(c("up", "down"), 10) ) double_enrich(deg) }
Run the code above in your browser using DataLab