do PCA analysis and warning a PCA plot
draw_pca(
exp,
group_list,
color = c("#2874C5", "#f87669", "#e6b707", "#868686", "#92C5DE", "#F4A582", "#66C2A5",
"#FC8D62", "#8DA0CB", "#E78AC3", "#A6D854", "#FFD92F", "#E5C494", "#B3B3B3"),
addEllipses = TRUE,
style = "default",
color.label = "Group",
title = "",
...
)a PCA plot according to exp and grouped by group_list.
A numeric matrix
A character or factor vector with one label per sample; character input will be converted to factor and unused levels will be dropped.
color vector
logical,add ellipses or not
plot style,"default","ggplot2"and "3D"
color legend label
plot title
other parameters from fviz_pca_ind
Xiaojie Sun
draw_heatmap;draw_volcano;draw_venn