View source: R/11_surv_box_plot.R
| exp_boxplot | R Documentation |
draw box plot for a hub gene expression matrix
exp_boxplot(
exp_hub,
xlab = NULL,
ylab = NULL,
p.label = FALSE,
color = c("#2fa1dd", "#f87669")
)
exp_hub |
an expression matrix for hubgenes |
xlab |
x axis title |
ylab |
y axis title |
p.label |
whether to show the exact p-value, if FALSE show significance symbols |
color |
color for boxplot |
box plots list for all genes in the matrix
Xiaojie Sun
exp_surv;box_surv
k = exp_boxplot(log2(exp_hub1+1));k[[1]]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.