Learn R Programming

tinyarray (version 3.0.0)

exp_boxplot: exp_boxplot

Description

draw box plot for a hub gene expression matrix

Usage

exp_boxplot(
  exp_hub,
  xlab = NULL,
  ylab = NULL,
  p.label = FALSE,
  color = c("#2fa1dd", "#f87669")
)

Value

box plots list for all genes in the matrix

Arguments

exp_hub

an expression matrix for hubgenes

xlab

x axis title

ylab

y axis title

p.label

whether to show the exact p-value, if FALSE show significance symbols

color

color for boxplot

Author

Xiaojie Sun

See Also

exp_surv;box_surv

Examples

Run this code
if (FALSE) { # requireNamespace("ggpubr", quietly = TRUE)
k = exp_boxplot(log2(exp_hub1+1));k[[1]]
}

Run the code above in your browser using DataLab