powered by
draw box plot for a hub gene expression matrix
exp_boxplot( exp_hub, xlab = NULL, ylab = NULL, p.label = FALSE, color = c("#2fa1dd", "#f87669") )
box plots list for all genes in the matrix
an expression matrix for hubgenes
x axis title
y axis title
whether to show the exact p-value, if FALSE show significance symbols
color for boxplot
Xiaojie Sun
exp_surv;box_surv
exp_surv
box_surv
if (FALSE) { # requireNamespace("ggpubr", quietly = TRUE) k = exp_boxplot(log2(exp_hub1+1));k[[1]] }
Run the code above in your browser using DataLab