| find_anno | R Documentation |
The function prints a short explanation plus the code used to obtain annotations. It only tests AnnoProbe 'type' values when no Bioconductor annotation package source exists for the GPL accession.
find_anno(gpl, install = FALSE, update = FALSE)
gpl |
a GEO platform accession |
install |
whether to install and library the package |
update |
whether to update the package |
No return value. The function prints available annotation resources and optionally installs a Bioconductor annotation package.
Xiaojie Sun
geo_download
## Not run:
try(find_anno("GPL570"), silent = TRUE)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.