| get_deg | R Documentation |
Do differential analysis according to an expression set and group information.
get_deg(
exp,
group_list,
ids = NULL,
logFC_cutoff = 1,
pvalue_cutoff = 0.05,
adjust = TRUE,
entriz = TRUE,
species = "human"
)
exp |
A numeric matrix |
group_list |
A character or factor vector with one label per sample; character input will be converted to factor and unused levels will be dropped. |
ids |
optional probe-to-symbol annotation table. If 'NULL', 'exp' is treated as a gene-level matrix and no ID conversion is performed. |
logFC_cutoff |
Cutoff value of logFC,1 by default. |
pvalue_cutoff |
Cutoff value of pvalue,0.05 by default. |
adjust |
a logical value; if TRUE, use |
entriz |
whether to convert symbols to Entrez IDs |
species |
choose human, mouse, or rat; default is human |
a deg data.frame
Xiaojie Sun
multi_deg;get_deg_all
## Not run:
if(requireNamespace("Biobase",quietly = TRUE)&
requireNamespace("AnnoProbe",quietly = TRUE)){
gse = "GSE42872"
a = geo_download(gse,destdir=tempdir())
find_anno(geo$gpl)
ids <- AnnoProbe::idmap(geo$gpl,destdir = tempdir())
Group = rep(c("control","treat"),each = 3)
Group = factor(Group)
deg = get_deg(geo$exp,Group,ids,entriz = FALSE)
head(deg)
}else{
if(!requireNamespace("AnnoProbe",quietly = TRUE)) {
warning("Package 'AnnoProbe' needed for this function to work.
Please install it by install.packages('AnnoProbe')",call. = FALSE)
}
if(!requireNamespace("Biobase",quietly = TRUE)) {
warning("Package 'Biobase' needed for this function to work.
Please install it by BiocManager::install('Biobase')",call. = FALSE)
}
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.