View source: R/8_tcga_group_trans_exp.R
| make_tcga_group | R Documentation |
make tcga group for given tcga sample names or expression matrix
make_tcga_group(exp)
exp |
sample names or an expression matrix/data.frame with sample names in its columns |
a group factor with normal and tumor, corresponding to the sample names
Xiaojie Sun
sam_filter;match_exp_cl
k = make_tcga_group(exp_hub1);table(k)
k2 = make_tcga_group(colnames(exp_hub1));table(k2)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.