View source: R/7_quick_double_enrich.R
| quick_enrich | R Documentation |
Perform enrichment analysis for a gene list; human is the default species.
quick_enrich(genes, kkgo_file = NULL, destdir = getwd(), species = "human")
genes |
a gene symbol or Entrez ID vector |
kkgo_file |
optional RDS cache filename for KEGG and GO results; when 'NULL', the function recomputes on every call and does not write a cache |
destdir |
destination directory used to save the cache file when 'kkgo_file' is provided |
species |
choose human, mouse, or rat; default is human |
enrichment results and dotplots
Xiaojie Sun
double_enrich
## Not run:
head(genes)
g = quick_enrich(genes,destdir = tempdir())
names(g)
g$kk
g$go
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.