Learn R Programming

tinyarray (version 3.0.0)

quick_enrich: quick_enrich

Description

Perform enrichment analysis for a gene list; human is the default species.

Usage

quick_enrich(genes, kkgo_file = NULL, destdir = getwd(), species = "human")

Value

enrichment results and dotplots

Arguments

genes

a gene symbol or Entrez ID vector

kkgo_file

optional RDS cache filename for KEGG and GO results; when `NULL`, the function recomputes on every call and does not write a cache

destdir

destination directory used to save the cache file when `kkgo_file` is provided

species

choose human, mouse, or rat; default is human

Author

Xiaojie Sun

See Also

double_enrich

Examples

Run this code
if (FALSE) {
head(genes)
g = quick_enrich(genes,destdir = tempdir())
names(g)
g$kk
g$go
}

Run the code above in your browser using DataLab