View source: R/8_tcga_group_trans_exp.R
| trans_ensembl_exp | R Documentation |
Transform rownames of an expression set from Ensembl IDs to gene symbols using the latest gene annotation.
trans_ensembl_exp(
exp,
mrna_only = FALSE,
lncrna_only = FALSE,
species = "human",
average = FALSE
)
exp |
expression matrix with Ensembl IDs as rownames |
mrna_only |
only keep mrna rows in result |
lncrna_only |
only keep lncrna rows in result |
species |
choose human, mouse, or rat; default is human |
average |
logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol. |
a transformed expression set with symbol
Xiaojie Sun
trans_exp_new
exp = matrix(rnorm(1000),ncol = 10)
rownames(exp) = sample(mRNA_anno$gene_id,100)
colnames(exp) = c(paste0("TCGA",1:5),paste0("GTEX",1:5))
k = trans_ensembl_exp(exp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.