Learn R Programming

tinyarray (version 3.0.0)

trans_ensembl_exp: trans_ensembl_exp

Description

Transform rownames of an expression set from Ensembl IDs to gene symbols using the latest gene annotation.

Usage

trans_ensembl_exp(
  exp,
  mrna_only = FALSE,
  lncrna_only = FALSE,
  species = "human",
  average = FALSE
)

Value

a transformed expression set with symbol

Arguments

exp

expression matrix with Ensembl IDs as rownames

mrna_only

only keep mrna rows in result

lncrna_only

only keep lncrna rows in result

species

choose human, mouse, or rat; default is human

average

logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.

Author

Xiaojie Sun

See Also

trans_exp_new