Transform rownames of an expression set from Ensembl IDs to gene symbols using the latest gene annotation.
trans_ensembl_exp(
exp,
mrna_only = FALSE,
lncrna_only = FALSE,
species = "human",
average = FALSE
)a transformed expression set with symbol
expression matrix with Ensembl IDs as rownames
only keep mrna rows in result
only keep lncrna rows in result
choose human, mouse, or rat; default is human
logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.
Xiaojie Sun
trans_exp_new