View source: R/8_tcga_group_trans_exp.R
| trans_entrezexp | R Documentation |
Transform rownames of an expression set from Entrez IDs to gene symbols
using clusterProfiler::bitr().
trans_entrezexp(entrezexp, species = "human", average = FALSE)
trans_entrez_exp(entrezexp, species = "human", average = FALSE)
entrezexp |
expression matrix with Entrez IDs as rownames |
species |
choose human, mouse, or rat; default is human |
average |
logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol. |
a transformed expression set with symbol
Xiaojie Sun
trans_exp
exp = matrix(rnorm(200),ncol = 10)
rownames(exp) = c("79691", "56271", "8662", "10394", "55630", "159162", "23541",
"79723", "54413", "22927", "92342", "23787", "5550", "8924",
"55274", "866", "8844", "353299", "587", "1473")
colnames(exp) = paste0("s",1:10)
exp2 = trans_entrezexp(exp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.