View source: R/8_tcga_group_trans_exp.R
| trans_exp_new | R Documentation |
Route expression-matrix ID conversion by type.
trans_exp_new(
exp,
mrna_only = FALSE,
lncrna_only = FALSE,
species = "human",
average = FALSE,
type = c("ensembl", "array", "entrez"),
ids = NULL,
id = NULL
)
exp |
expression matrix |
mrna_only |
only keep mrna rows in result when 'type = "ensembl"' |
lncrna_only |
only keep lncrna rows in result when 'type = "ensembl"' |
species |
choose human, mouse, or rat; default is human |
average |
logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol. |
type |
conversion type, one of 'ensembl', 'array', or 'entrez' |
ids |
annotation table used when 'type = "array"' |
id |
alias of 'ids'; kept for compatibility |
a transformed expression set with symbol
Xiaojie Sun
trans_ensembl_exp;trans_array;trans_entrezexp
exp = matrix(rnorm(1000),ncol = 10)
rownames(exp) = sample(mRNA_anno$gene_id,100)
colnames(exp) = c(paste0("TCGA",1:5),paste0("GTEX",1:5))
k = trans_exp_new(exp)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.