Learn R Programming

tinyarray (version 3.0.0)

trans_exp_new: trans_exp_new

Description

Route expression-matrix ID conversion by type.

Usage

trans_exp_new(
  exp,
  mrna_only = FALSE,
  lncrna_only = FALSE,
  species = "human",
  average = FALSE,
  type = c("ensembl", "array", "entrez"),
  ids = NULL,
  id = NULL
)

Value

a transformed expression set with symbol

Arguments

exp

expression matrix

mrna_only

only keep mrna rows in result when `type = "ensembl"`

lncrna_only

only keep lncrna rows in result when `type = "ensembl"`

species

choose human, mouse, or rat; default is human

average

logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.

type

conversion type, one of `ensembl`, `array`, or `entrez`

ids

annotation table used when `type = "array"`

id

alias of `ids`; kept for compatibility

Author

Xiaojie Sun

See Also

trans_ensembl_exp;trans_array;trans_entrezexp