Route expression-matrix ID conversion by type.
trans_exp_new(
exp,
mrna_only = FALSE,
lncrna_only = FALSE,
species = "human",
average = FALSE,
type = c("ensembl", "array", "entrez"),
ids = NULL,
id = NULL
)a transformed expression set with symbol
expression matrix
only keep mrna rows in result when `type = "ensembl"`
only keep lncrna rows in result when `type = "ensembl"`
choose human, mouse, or rat; default is human
logical, if TRUE, average rows that map to the same target symbol; if FALSE, keep the first matched row for each symbol.
conversion type, one of `ensembl`, `array`, or `entrez`
annotation table used when `type = "array"`
alias of `ids`; kept for compatibility
Xiaojie Sun
trans_ensembl_exp;trans_array;trans_entrezexp